<?php

namespace Drupal\view_mode_switch\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldFilteredMarkup;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'view_mode_switch_default' formatter.
 *
 * @FieldFormatter(
 *   id = "view_mode_switch_default",
 *   label = @Translation("Default"),
 *   field_types = {
 *     "view_mode_switch"
 *   }
 * )
 */
class ViewModeSwitchDefaultFormatter extends ViewModeSwitchFormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $entity = $items->getEntity();

    foreach ($items as $delta => $item) {
      // Load view mode.
      $view_mode = $this->entityTypeManager->getStorage('entity_view_mode')
        ->load($entity->getEntityTypeId() . '.' . $item->value);

      // View mode found -> display its human-readable label.
      if ($view_mode) {
        $elements[$delta] = [
          '#markup' => $view_mode->label(),
          '#allowed_tags' => FieldFilteredMarkup::allowedTags(),
        ];
      }
    }

    return $elements;
  }

}
