<?php

namespace Drupal\view_mode_switch\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldFilteredMarkup;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'view_mode_switch_machine_name' formatter.
 *
 * @FieldFormatter(
 *   id = "view_mode_switch_machine_name",
 *   label = @Translation("Machine name"),
 *   field_types = {
 *     "view_mode_switch"
 *   }
 * )
 */
class ViewModeSwitchMachineNameFormatter extends ViewModeSwitchFormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $entity = $items->getEntity();

    foreach ($items as $delta => $item) {
      $value = $item->value;

      /* @var \Drupal\Core\Entity\Entity\EntityViewMode|null $view_mode */
      $view_mode = $this->entityTypeManager->getStorage('entity_view_mode')
        ->load($entity->getEntityTypeId() . '.' . $value);

      // View mode found -> display its machine name.
      if ($view_mode) {
        $elements[$delta] = [
          '#markup' => $value,
          '#allowed_tags' => FieldFilteredMarkup::allowedTags(),
        ];
      }
    }

    return $elements;
  }

}
