<?php

namespace Drupal\view_mode_switch\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Interface for view mode switch lists of field items.
 */
interface ViewModeSwitchItemListInterface extends FieldItemListInterface {

  /**
   * Returns the view modes allowed to switch to.
   *
   * @return array
   *   A keyed array of view mode names for all configured allowed view modes.
   *   Both the key and the value are the view mode name.
   *
   * @see \Drupal\view_mode_switch\Plugin\Field\FieldType\ViewModeSwitchItemInterface::getAllowedViewModes()
   */
  public function getAllowedViewModes();

  /**
   * Returns the view mode to switch to.
   *
   * @return \Drupal\Core\Entity\EntityViewModeInterface|null
   *   The view mode entity on success, otherwise NULL.
   *
   * @see \Drupal\view_mode_switch\Plugin\Field\FieldType\ViewModeSwitchItemInterface::getViewMode()
   */
  public function getViewMode();

  /**
   * Returns the view modes to switch.
   *
   * @return array
   *   A keyed array of view mode names for all configured origin view modes.
   *   Both the key and the value are the view mode name.
   *
   * @see \Drupal\view_mode_switch\Plugin\Field\FieldType\ViewModeSwitchItemInterface::getOriginViewModes()
   */
  public function getOriginViewModes();

  /**
   * Returns whether the field is applicable for the given origin view mode.
   *
   * @param string $view_mode
   *   A view mode name.
   *
   * @return bool
   *   Whether the field is applicable for the given origin view mode.
   *
   * @see \Drupal\view_mode_switch\Plugin\Field\FieldType\ViewModeSwitchItemInterface::isApplicable()
   */
  public function isApplicable($view_mode);

  /**
   * Returns whether the field is responsible for the given origin view mode.
   *
   * @param string $view_mode
   *   A view mode name.
   *
   * @return bool
   *   Whether the field is responsible for the given origin view mode.
   *
   * @see \Drupal\view_mode_switch\Plugin\Field\FieldType\ViewModeSwitchItemInterface::isResponsible()
   */
  public function isResponsible($view_mode);

}
