<?php

namespace Drupal\view_mode_switch;

use Drupal\Core\Entity\EntityViewModeInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Interface for view mode helper service classes.
 */
interface ViewModeHelperInterface {

  /**
   * Alter entity view mode delete confirm form.
   *
   * This method adds potential custom view mode switch field storage
   * configuration changes triggered when an entity view mode is deleted that is
   * used as an origin view mode.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @see \Drupal\Core\Config\Entity\ConfigDependencyDeleteFormTrait::addDependencyListsToForm()
   */
  public function confirmFormAlter(array &$form, FormStateInterface $form_state);

  /**
   * Returns the name of an entity view mode.
   *
   * @param \Drupal\Core\Entity\EntityViewModeInterface $entity
   *   The entity view mode object.
   *
   * @return string
   *   The entity view mode name on success, otherwise NULL.
   */
  public function getName(EntityViewModeInterface $entity);

  /**
   * Act before entity view mode deletion.
   *
   * This method ensures view mode switch field storage configuration changes
   * needed when an entity view mode is deleted that is used as an origin view
   * mode.
   *
   * @param \Drupal\Core\Entity\EntityViewModeInterface $entity
   *   The entity object for the entity view mode that is about to be deleted.
   */
  public function preDelete(EntityViewModeInterface $entity);

}
